#region license

/*
EasyBuildSQL - is a C# library oriented to help to developers to build sql sentence in differents database engine. 
EasyBuildSQL is developed to .NET Framework.
 
Copyright (C) 2010 - Alejandro Genovesi
http://sourceforge.net/projects/easybuildsql/ 
Contributor : Arturo Martinez

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
 License as published by the Free Software Foundation; either
 version 2 of the License, or (at your option) any later version.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.

 You should have received a copy of the GNU Library General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA 
 
*/

#endregion

using System;
using System.Collections.Generic;
using System.Text;
using System.Data;
using System.Data.Common;
using System.Data.SqlClient;
using System.IO;

namespace EasyBuildSQL
{
  public abstract class SQLSentence
  {
    private DbCommand fCommand;
    private StringBuilder fSentence;
    protected DataBaseType fDBType = DataBaseType.MSSQL;

    public string SentenceSQL
    {
      get
      {
        return fSentence.ToString();
      }
    }

    public SQLSentence( DbCommand Command, DataBaseType DBType)
    {
      fSentence = new StringBuilder();

      fCommand = Command;
      fDBType = DBType;
    }

    protected void AddText(string SQL)
    {
      fSentence.AppendLine(SQL);
    }

    protected DbParameter CreateParameter(string Name, DbType Type, object Value, int Large)
    {
      DbParameter pNew = fCommand.CreateParameter();

      pNew.ParameterName = Name.ToUpper();
      pNew.DbType = Type;
      pNew.Direction = ParameterDirection.Input;

      if (Value != null)
          pNew.Value = Value;

      if (Large != 0)
          pNew.Size = Large;

      fCommand.Parameters.Add(pNew);

      return pNew;
    }

    protected DbParameter CreateParameter(string Name, DbType Type, object Value)
    {
      return CreateParameter(Name, Type, Value, 0);
    }

    protected void ClearSentence()
    {
      fSentence.Length = 0;
    }
  }

  public class ebSQLSentence : SQLSentence
  {
      public ebSQLSentence(DbCommand Command, DataBaseType DBType)
      : base(Command, DBType)
    {
    }

    public void Add(string SQL)
    {
      AddText(SQL);
    }

    public DbParameter AddParameter(string Name, DbType Type, object Value, int Large)
    {
      return CreateParameter(Name, Type, Value, Large);
    }

    public DbParameter AddParameter(string Name, DbType Type, object Value)
    {
      return CreateParameter(Name, Type, Value, 0);
    }

    public void Clear()
    {
      ClearSentence();
    }
  }
}
